@@ -29,6 +29,7 @@
 #include "gdkinternals.h"
 #include "gdkpixbuf.h"
 #include "gdkscreen.h"
+#include "gdkalias.h"
 
 static GdkGC *gdk_pixmap_create_gc      (GdkDrawable     *drawable,
                                          GdkGCValues     *values,
@@ -89,12 +90,21 @@ static void   gdk_pixmap_draw_lines     (GdkDrawable     *drawable,
 					 GdkGC           *gc,
 					 GdkPoint        *points,
 					 gint             npoints);
-static void   gdk_pixmap_draw_glyphs    (GdkDrawable      *drawable,
-                                         GdkGC            *gc,
-                                         PangoFont        *font,
-                                         gint              x,
-                                         gint              y,
-                                         PangoGlyphString *glyphs);
+
+static void gdk_pixmap_draw_glyphs             (GdkDrawable      *drawable,
+						GdkGC            *gc,
+						PangoFont        *font,
+						gint              x,
+						gint              y,
+						PangoGlyphString *glyphs);
+static void gdk_pixmap_draw_glyphs_transformed (GdkDrawable      *drawable,
+						GdkGC            *gc,
+						PangoMatrix      *matrix,
+						PangoFont        *font,
+						gint              x,
+						gint              y,
+						PangoGlyphString *glyphs);
+
 static void   gdk_pixmap_draw_image     (GdkDrawable     *drawable,
                                          GdkGC           *gc,
                                          GdkImage        *image,
@@ -116,7 +126,10 @@ static void   gdk_pixmap_draw_pixbuf    (GdkDrawable     *drawable,
 					 GdkRgbDither     dither,
 					 gint             x_dither,
 					 gint             y_dither);
-
+static void  gdk_pixmap_draw_trapezoids (GdkDrawable     *drawable,
+					 GdkGC	         *gc,
+					 GdkTrapezoid    *trapezoids,
+					 gint             n_trapezoids);
 
 static void   gdk_pixmap_real_get_size  (GdkDrawable     *drawable,
                                          gint            *width,
@@ -131,6 +144,8 @@ static GdkImage* gdk_pixmap_copy_to_image (GdkDrawable *drawable,
 					   gint         width,
 					   gint         height);
 
+static cairo_surface_t *gdk_pixmap_ref_cairo_surface (GdkDrawable *drawable);
+
 static GdkVisual*   gdk_pixmap_real_get_visual   (GdkDrawable *drawable);
 static gint         gdk_pixmap_real_get_depth    (GdkDrawable *drawable);
 static void         gdk_pixmap_real_set_colormap (GdkDrawable *drawable,
@@ -138,39 +153,9 @@ static void         gdk_pixmap_real_set_colormap (GdkDrawable *drawable,
 static GdkColormap* gdk_pixmap_real_get_colormap (GdkDrawable *drawable);
 static GdkScreen*   gdk_pixmap_real_get_screen   (GdkDrawable *drawable);
 
-static void gdk_pixmap_init       (GdkPixmapObject      *pixmap);
-static void gdk_pixmap_class_init (GdkPixmapObjectClass *klass);
 static void gdk_pixmap_finalize   (GObject              *object);
 
-static gpointer parent_class = NULL;
-
-GType
-gdk_pixmap_get_type (void)
-{
-  static GType object_type = 0;
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info =
-      {
-        sizeof (GdkPixmapObjectClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) gdk_pixmap_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GdkPixmapObject),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) gdk_pixmap_init,
-      };
-      
-      object_type = g_type_register_static (GDK_TYPE_DRAWABLE,
-                                            "GdkPixmap",
-                                            &object_info, 0);
-    }
-  
-  return object_type;
-}
+G_DEFINE_TYPE (GdkPixmapObject, gdk_pixmap, GDK_TYPE_DRAWABLE)
 
 static void
 gdk_pixmap_init (GdkPixmapObject *pixmap)
@@ -185,8 +170,6 @@ gdk_pixmap_class_init (GdkPixmapObjectClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GdkDrawableClass *drawable_class = GDK_DRAWABLE_CLASS (klass);
   
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->finalize = gdk_pixmap_finalize;
 
   drawable_class->create_gc = gdk_pixmap_create_gc;
@@ -200,8 +183,10 @@ gdk_pixmap_class_init (GdkPixmapObjectClass *klass)
   drawable_class->draw_segments = gdk_pixmap_draw_segments;
   drawable_class->draw_lines = gdk_pixmap_draw_lines;
   drawable_class->draw_glyphs = gdk_pixmap_draw_glyphs;
+  drawable_class->draw_glyphs_transformed = gdk_pixmap_draw_glyphs_transformed;
   drawable_class->draw_image = gdk_pixmap_draw_image;
   drawable_class->draw_pixbuf = gdk_pixmap_draw_pixbuf;
+  drawable_class->draw_trapezoids = gdk_pixmap_draw_trapezoids;
   drawable_class->get_depth = gdk_pixmap_real_get_depth;
   drawable_class->get_screen = gdk_pixmap_real_get_screen;
   drawable_class->get_size = gdk_pixmap_real_get_size;
@@ -209,6 +194,7 @@ gdk_pixmap_class_init (GdkPixmapObjectClass *klass)
   drawable_class->get_colormap = gdk_pixmap_real_get_colormap;
   drawable_class->get_visual = gdk_pixmap_real_get_visual;
   drawable_class->_copy_to_image = gdk_pixmap_copy_to_image;
+  drawable_class->ref_cairo_surface = gdk_pixmap_ref_cairo_surface;
 }
 
 static void
@@ -219,7 +205,7 @@ gdk_pixmap_finalize (GObject *object)
   g_object_unref (obj->impl);
   obj->impl = NULL;
   
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gdk_pixmap_parent_class)->finalize (object);
 }
 
 static GdkGC *
@@ -370,6 +356,20 @@ gdk_pixmap_draw_glyphs (GdkDrawable      *drawable,
   gdk_draw_glyphs (private->impl, gc, font, x, y, glyphs);
 }
 
+static void
+gdk_pixmap_draw_glyphs_transformed (GdkDrawable      *drawable,
+				    GdkGC            *gc,
+				    PangoMatrix      *matrix,
+				    PangoFont        *font,
+				    gint              x,
+				    gint              y,
+				    PangoGlyphString *glyphs)
+{
+  GdkPixmapObject *private = (GdkPixmapObject *)drawable;
+
+  gdk_draw_glyphs_transformed (private->impl, gc, matrix, font, x, y, glyphs);
+}
+
 static void
 gdk_pixmap_draw_image (GdkDrawable     *drawable,
                        GdkGC           *gc,
@@ -408,6 +408,17 @@ gdk_pixmap_draw_pixbuf (GdkDrawable     *drawable,
 		   dither, x_dither, y_dither);
 }
 
+static void
+gdk_pixmap_draw_trapezoids (GdkDrawable     *drawable,
+			    GdkGC	    *gc,
+			    GdkTrapezoid    *trapezoids,
+			    gint             n_trapezoids)
+{
+  GdkPixmapObject *private = (GdkPixmapObject *)drawable;
+
+  gdk_draw_trapezoids (private->impl, gc, trapezoids, n_trapezoids);
+}
+
 static void
 gdk_pixmap_real_get_size (GdkDrawable *drawable,
                           gint *width,
@@ -477,6 +488,12 @@ gdk_pixmap_copy_to_image (GdkDrawable     *drawable,
 				     width, height);
 }
 
+static cairo_surface_t *
+gdk_pixmap_ref_cairo_surface (GdkDrawable *drawable)
+{
+  return _gdk_drawable_ref_cairo_surface (((GdkPixmapObject*)drawable)->impl);
+}
+
 static GdkBitmap *
 make_solid_mask (GdkScreen *screen, gint width, gint height)
 {
@@ -631,3 +648,6 @@ gdk_pixmap_real_get_screen (GdkDrawable *drawable)
 {
     return gdk_drawable_get_screen (GDK_PIXMAP_OBJECT (drawable)->impl);
 }
+
+#define __GDK_PIXMAP_C__
+#include "gdkaliasdef.c"
