@@ -1,5 +1,5 @@
 /* GTK - The GIMP Toolkit
- * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+ * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Jsh MacDonald
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include "gtkintl.h"
 #include "gtkmenu.h"
 #include "gtkmenuitem.h"
@@ -34,6 +35,9 @@
 #include "gtkoptionmenu.h"
 #define GTK_DISABLE_DEPRECATED
 
+#include "gtkprivate.h"
+#include "gtkalias.h"
+
 #define CHILD_LEFT_SPACING        4
 #define CHILD_RIGHT_SPACING       1
 #define CHILD_TOP_SPACING         1
@@ -58,8 +62,6 @@ static const GtkOptionMenuProps default_props = {
   0
 };
 
-static void gtk_option_menu_class_init      (GtkOptionMenuClass *klass);
-static void gtk_option_menu_init            (GtkOptionMenu      *option_menu);
 static void gtk_option_menu_destroy         (GtkObject          *object);
 static void gtk_option_menu_set_property    (GObject            *object,
 					     guint               prop_id,
@@ -112,37 +114,9 @@ enum
   LAST_PROP
 };
 
-static GtkButtonClass *parent_class = NULL;
-static guint           signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
-
-GType
-gtk_option_menu_get_type (void)
-{
-  static GType option_menu_type = 0;
-
-  if (!option_menu_type)
-    {
-      static const GTypeInfo option_menu_info =
-      {
-	sizeof (GtkOptionMenuClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-	(GClassInitFunc) gtk_option_menu_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	sizeof (GtkOptionMenu),
-	0,		/* n_preallocs */
-	(GInstanceInitFunc) gtk_option_menu_init,
-      };
-
-      option_menu_type =
-	g_type_register_static (GTK_TYPE_BUTTON, "GtkOptionMenu",
-				&option_menu_info, 0);
-    }
-
-  return option_menu_type;
-}
+G_DEFINE_TYPE (GtkOptionMenu, gtk_option_menu, GTK_TYPE_BUTTON)
 
 static void
 gtk_option_menu_class_init (GtkOptionMenuClass *class)
@@ -150,19 +124,15 @@ gtk_option_menu_class_init (GtkOptionMenuClass *class)
   GObjectClass *gobject_class;
   GtkObjectClass *object_class;
   GtkWidgetClass *widget_class;
-  GtkButtonClass *button_class;
   GtkContainerClass *container_class;
 
   gobject_class = (GObjectClass*) class;
   object_class = (GtkObjectClass*) class;
   widget_class = (GtkWidgetClass*) class;
-  button_class = (GtkButtonClass*) class;
   container_class = (GtkContainerClass*) class;
 
-  parent_class = g_type_class_peek_parent (class);
-
   signals[CHANGED] =
-    g_signal_new ("changed",
+    g_signal_new (I_("changed"),
                   G_OBJECT_CLASS_TYPE (class),
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GtkOptionMenuClass, changed),
@@ -189,23 +159,23 @@ gtk_option_menu_class_init (GtkOptionMenuClass *class)
   g_object_class_install_property (gobject_class,
                                    PROP_MENU,
                                    g_param_spec_object ("menu",
-                                                        _("Menu"),
-                                                        _("The menu of options"),
+                                                        P_("Menu"),
+                                                        P_("The menu of options"),
                                                         GTK_TYPE_MENU,
-                                                        G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                        GTK_PARAM_READWRITE));
   
   gtk_widget_class_install_style_property (widget_class,
-					   g_param_spec_boxed ("indicator_size",
-							       _("Indicator Size"),
-							       _("Size of dropdown indicator"),
+					   g_param_spec_boxed ("indicator-size",
+							       P_("Indicator Size"),
+							       P_("Size of dropdown indicator"),
 							       GTK_TYPE_REQUISITION,
-							       G_PARAM_READABLE));
+							       GTK_PARAM_READABLE));
   gtk_widget_class_install_style_property (widget_class,
-					   g_param_spec_boxed ("indicator_spacing",
-							       _("Indicator Spacing"),
-							       _("Spacing around indicator"),
+					   g_param_spec_boxed ("indicator-spacing",
+							       P_("Indicator Spacing"),
+							       P_("Spacing around indicator"),
 							       GTK_TYPE_BORDER,
-							       G_PARAM_READABLE));
+							       GTK_PARAM_READABLE));
 }
 
 static GType
@@ -305,7 +275,7 @@ gtk_option_menu_remove_menu (GtkOptionMenu *option_menu)
   if (option_menu->menu)
     {
       if (GTK_MENU_SHELL (option_menu->menu)->active)
-	g_signal_emit_by_name (option_menu->menu, "cancel", 0);
+	gtk_menu_shell_cancel (GTK_MENU_SHELL (option_menu->menu));
       
       gtk_menu_detach (GTK_MENU (option_menu->menu));
     }
@@ -337,6 +307,7 @@ gtk_option_menu_set_history (GtkOptionMenu *option_menu,
  * items are numbered from top to bottom, starting with 0. 
  * 
  * Return value: index of the selected menu item, or -1 if there are no menu items
+ * Deprecated: 2.4: Use #GtkComboBox instead.
  **/
 gint
 gtk_option_menu_get_history (GtkOptionMenu *option_menu)
@@ -411,8 +382,8 @@ gtk_option_menu_destroy (GtkObject *object)
   if (option_menu->menu)
     gtk_widget_destroy (option_menu->menu);
 
-  if (GTK_OBJECT_CLASS (parent_class)->destroy)
-    (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+  if (GTK_OBJECT_CLASS (gtk_option_menu_parent_class)->destroy)
+    (* GTK_OBJECT_CLASS (gtk_option_menu_parent_class)->destroy) (object);
 }
 
 static void
@@ -1058,3 +1029,6 @@ gtk_option_menu_scroll_event (GtkWidget          *widget,
   return TRUE;
 }
 
+#define __GTK_OPTION_MENU_C__
+#include "gtkaliasdef.c"
+
